aboutsummaryrefslogtreecommitdiffstats
path: root/xen/arch/x86/x86_64
diff options
context:
space:
mode:
authorDavid Vrabel <david.vrabel@citrix.com>2012-10-09 12:46:27 +0100
committerDavid Vrabel <david.vrabel@citrix.com>2012-10-09 12:46:27 +0100
commit8590f0801e5f739f416b129c88e360ebb6974921 (patch)
treeb5c07bba7d66f4eb66d2507b047241a978513134 /xen/arch/x86/x86_64
parent5520dd2779bd324b9ca42ff37510006fb1b88209 (diff)
downloadxen-8590f0801e5f739f416b129c88e360ebb6974921.tar.gz
xen-8590f0801e5f739f416b129c88e360ebb6974921.tar.bz2
xen-8590f0801e5f739f416b129c88e360ebb6974921.zip
trace: rename trace_hypercall() to __trace_hypercall_entry()
Tracing functions that don't check tb_init_done are (by convention) prefixed with __. Signed-off-by: David Vrabel <david.vrabel@citrix.com> Committed-by: Keir Fraser <keir@xen.org>
Diffstat (limited to 'xen/arch/x86/x86_64')
-rw-r--r--xen/arch/x86/x86_64/compat/entry.S4
-rw-r--r--xen/arch/x86/x86_64/entry.S4
2 files changed, 4 insertions, 4 deletions
diff --git a/xen/arch/x86/x86_64/compat/entry.S b/xen/arch/x86/x86_64/compat/entry.S
index 2f606ab925..e6b52f345e 100644
--- a/xen/arch/x86/x86_64/compat/entry.S
+++ b/xen/arch/x86/x86_64/compat/entry.S
@@ -59,8 +59,8 @@ UNLIKELY_END(msi_check)
#endif
cmpb $0,tb_init_done(%rip)
UNLIKELY_START(ne, compat_trace)
- call trace_hypercall
- /* Now restore all the registers that trace_hypercall clobbered */
+ call __trace_hypercall_entry
+ /* Restore the registers that __trace_hypercall_entry clobbered. */
movl UREGS_rax+SHADOW_BYTES(%rsp),%eax /* Hypercall # */
movl UREGS_rbx+SHADOW_BYTES(%rsp),%edi /* Arg 1 */
movl UREGS_rcx+SHADOW_BYTES(%rsp),%esi /* Arg 2 */
diff --git a/xen/arch/x86/x86_64/entry.S b/xen/arch/x86/x86_64/entry.S
index 74a40758b2..ffb9314f40 100644
--- a/xen/arch/x86/x86_64/entry.S
+++ b/xen/arch/x86/x86_64/entry.S
@@ -159,8 +159,8 @@ ENTRY(syscall_enter)
#endif
cmpb $0,tb_init_done(%rip)
UNLIKELY_START(ne, trace)
- call trace_hypercall
- /* Now restore all the registers that trace_hypercall clobbered */
+ call __trace_hypercall_entry
+ /* Restore the registers that __trace_hypercall_entry clobbered. */
movq UREGS_rax+SHADOW_BYTES(%rsp),%rax /* Hypercall # */
movq UREGS_rdi+SHADOW_BYTES(%rsp),%rdi /* Arg 1 */
movq UREGS_rsi+SHADOW_BYTES(%rsp),%rsi /* Arg 2 */